--==========================================================
-- Design units : AssocMemStim
--                (entitiy, architecture and configuration)
--
-- File name    : AssocMemStim.vhd
--
-- Purpose      : Stimuli generator for associative memory 
--
-- Limitations  : 
--
-- Library      : WORK
--
-- Dependencies : NONE
--
-- Author       : Claus-Juergen Thomas, REFT
--
-- Simulator    : Synopsys V3.1a on SUN SPARCstation 10
--
-------------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
-- V1.0    cjt    16.10.95       new
--===========================================================

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;
USE work.ELEMpack.all;
USE work.AssocMempack.all;

ENTITY AssocMemStim IS
  GENERIC (M : Positive := 4;
           N : Positive := 3);
  PORT(WriteEnable : OUT std_logic;
       Data        : OUT std_logic_vector(M-1 DOWNTO 0);
       Mask        : OUT std_logic_vector(M-1 DOWNTO 0);
       Address     : OUT std_logic_vector(N-1 DOWNTO 0);
       Store       : OUT std_logic;
       SelectAdrMat: OUT std_logic;
       Reset       : OUT std_logic;
       Clock       : OUT std_logic);
END AssocMemStim;

--==========================ARCHITECTURE=====================

ARCHITECTURE Behavior OF AssocMemStim IS

BEGIN

WriteEnable  <= '0' AFTER   0 Ns, '1' AFTER  40 Ns,
                '0' AFTER  60 Ns, '1' AFTER 140 Ns,
                '0' AFTER 160 Ns, '1' AFTER 240 Ns,
                '0' AFTER 260 Ns;

Data         <= "0110" AFTER   0 Ns,
                "1000" AFTER 100 Ns,
                "0011" AFTER 200 Ns,
                "0001" AFTER 300 Ns;

Mask         <= "0000" AFTER   0 Ns,
                "1110" AFTER 400 Ns;

Address      <= "001" AFTER   0 Ns,
                "010" AFTER 100 Ns,
                "100" AFTER 200 Ns,
                "000" AFTER 300 Ns;

Store        <= '1' AFTER   0 Ns, '0' AFTER  90 Ns,
                '1' AFTER 100 Ns, '0' AFTER 190 Ns,
                '1' AFTER 200 Ns, '0' AFTER 290 Ns,
                '1' AFTER 300 Ns, '0' AFTER 480 Ns; 

SelectAdrMat <= '0' AFTER   0 Ns,
                '1' AFTER 480 Ns;

Reset        <= '1' AFTER  0 Ns,
                '0' AFTER 10 Ns,
                '1' AFTER 20 Ns,
                '0' AFTER 790 Ns;

Clock        <= '0' AFTER   0 Ns, '1' AFTER  50 Ns,
                '0' AFTER 100 Ns, '1' AFTER 150 Ns,
                '0' AFTER 200 Ns, '1' AFTER 250 Ns,
                '0' AFTER 300 Ns, '1' AFTER 350 Ns,
                '0' AFTER 400 Ns, '1' AFTER 450 Ns,
                '0' AFTER 500 Ns, '1' AFTER 550 Ns,
                '0' AFTER 600 Ns, '1' AFTER 650 Ns,
                '0' AFTER 700 Ns, '1' AFTER 750 Ns,
                '0' AFTER 800 Ns, '1' AFTER 850 Ns,
                '0' AFTER 900 Ns, '1' AFTER 950 Ns;

END Behavior;

--==========================CONFIGURATION====================
