--==========================================================
-- Design units : FiFoTestbench
--
-- File name    : FIFOtestbench.vhd
--
-- Purpose      : Testbench for FIFO Storage-Circuit
--
-- Limitations  : none
--
-- Library      : work
--
-- Dependencies : FIFOpack, FIFOstage, FIFOstruc, FIFOstim,
--
--                FIFObehave
--
-- Author       : Hans-Peter Eich, Claus-Juergen Thomas, REFT
--
-- Simulator    : Synopsys V3.1a on SUN SPARCstation 10
--
-------------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
-- V1.0    hpe    02.04.95       new
-- V2.0    cjt    16.11.95       std_logic, external stimuli, ESA-standard
--===========================================================

LIBRARY IEEE;
USE ieee.std_logic_1164.all;
USE work.FIFOpack.all;

ENTITY FIFOtestbench IS
END FIFOtestbench;

--============================ARCHITECTURE==================

ARCHITECTURE Structure OF FIFOtestbench IS

  CONSTANT N : Positive := 4; -- Number of stages
  CONSTANT M : Positive := 4; -- word length

  SIGNAL DataIn,DataOut: std_logic_vector(M-1 DOWNTO 0);
  SIGNAL ShiftIn,ShiftOut,MasterReset: std_logic;
  SIGNAL InputReady,OutputReady: std_logic_vector(0 to 0);
  SIGNAL InputReady_beh,OutputReady_beh: std_logic;
  SIGNAL DataInInt,DataOutInt : Integer;
  SIGNAL MemoryFlag: std_logic_vector(N-1 downto 0);


BEGIN

MUT : FIFOstruc                -- Model under test
  GENERIC MAP (M,N)
  PORT MAP (DataIn,
            ShiftIn,
            ShiftOut,
            MasterReset,
            DataOut,
            InputReady,
            OutputReady);

SPEC : FIFObehave              -- Specification : behavioral description
  GENERIC MAP (N)
  PORT MAP (DataInInt,
            ShiftIn,
            ShiftOut,
            MasterReset,
            DataOutInt,
       MemoryFlag,
            InputReady_beh,
            OutputReady_beh);

STIM : FIFOstim                -- Stimuli generator
  GENERIC MAP (M)
  PORT MAP (DataInInt,
            DataIn,
            ShiftIn,
            ShiftOut,
            MasterReset);

END Structure;

--============================CONFIGURATION=================

CONFIGURATION FIFOtestbench_config OF FIFOtestbench IS
FOR Structure

  FOR MUT : FIFOstruc
    USE ENTITY work.FIFOstruc(Structure);
  END FOR;

  FOR SPEC : FIFObehave
    USE ENTITY work.FIFObehave(Behavior);
  END FOR;

  FOR STIM : FIFOstim
    USE ENTITY work.FIFOstim(Behavior);
  END FOR;

END FOR;
END FIFOtestbench_config;
